<?php 
$translations = array(
	'General_Locale' => 'uk_UA.UTF-8',
	'General_TranslatorName' => 'Joseph Chereshnovsky, Anton Andriyevskyy',
	'General_TranslatorEmail' => 'joseph.chereshnovsky@gmail.com, x.meglio@gmail.com',
	'General_EnglishLanguageName' => 'Ukrainian',
	'General_OriginalLanguageName' => 'Українська',
	'General_Unknown' => 'Невідомо',
	'General_Required' => '%s необхідно',
	'General_Error' => 'Помилка',
	'General_Warning' => 'Застереження',
	'General_BackToHomepage' => 'Назад до головної сторінки Piwik',
	'General_Yes' => 'Так',
	'General_No' => 'Ні',
	'General_Delete' => 'Видалити',
	'General_Edit' => 'Редагувати',
	'General_Ok' => 'Ok',
	'General_Close' => 'Закрити',
	'General_Logout' => 'Вийти',
	'General_Done' => 'Виконано',
	'General_LoadingData' => 'Завантаження даних...',
	'General_ErrorRequest' => 'Ой&hellip; запит викликав помилку, будь ласка спробуйте знову.',
	'General_Next' => 'Далі',
	'General_Previous' => 'Назад',
	'General_Table' => 'Таблиця',
	'General_Piechart' => 'Кругова діаграма',
	'General_TagCloud' => 'Хмара тегів',
	'General_VBarGraph' => 'Гістограма',
	'General_Refresh' => 'Оновити сторінку',
	'General_ColumnNbUniqVisitors' => 'Унікальні відвідувачі',
	'General_ColumnNbVisits' => 'Відвідування',
	'General_ColumnLabel' => 'Напис',
	'General_Save' => 'Зберегти',
	'General_HelloUser' => 'Привіт, %s!',
	'General_OpenSourceWebAnalytics' => 'Відкрита веб-аналітика',
	'General_YourDashboard' => 'Центр керування',
	'General_API' => 'API',
	'General_Widgets' => 'Віджет',
	'General_Settings' => 'Налаштування',
	'General_GiveUsYourFeedback' => 'Надішліть нам відгук!',
	'General_Search' => 'Пошук',
	'General_Others' => 'Інші',
	'General_Export' => 'Експорт',
	'General_Visitors' => 'Відвідувачі',
	'General_ColumnActionsPerVisit' => 'Дій на кожне відвідування',
	'General_ColumnAvgTimeOnSite' => 'Середній час на сайті',
	'General_ColumnBounceRate' => 'Частка відсіювання (Bounce Rate)',
	'General_ColumnPageviews' => 'Переглядів сторінок',
	'General_ColumnUniquePageviews' => 'Унікальних переглядів сорінок',
	'General_Website' => 'Веб-сайт',
	'General_NoDataForGraph' => 'Немає даних для цього графіку',
	'General_NoDataForTagCloud' => 'Немає даних для цієї хмари тегів',
	'General_DisplayNormalTable' => 'Показати звичайну таблицю',
	'General_DisplayMoreData' => 'Показати більше даних',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s це спільний проект. %s Якщо тобі подобається Piwik, можеш долучитися! Глянь %s Як зробити свій вклад в Piwik? %s',
	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'На даний час переглядається демонстраційна версія %s; %sзавантажити%s повну версію! Гляньте %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s в наявності. %s Будьласка поновіть негайно!%s (дивитися %s зміни%s).',
	'General_BackToPiwik' => 'Повернутися до Piwik',
	'API_QuickDocumentation' => '<h2>Коротка документація з API</h2><p>Якщо ви не маєте даних для сьогоднішнього дня, Ви можете спершу <a href=\'misc/generateVisits.php\' target=_blank>згенерувати випадкові дані</a> використовуючи Генератор Відвідувань.</p><p>Ви можете спробувати різні формати доступні для кожного методу. Отримати будь-які дані з Piwik - дуже легко!</p><p><b>Детальніше у <a href=\'http://dev.piwik.org/trac/wiki/API\'>Офіційній Документації з API</a> або <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>Довіднику з API</a>.</b></P><h2>Ідентифікація користувача</h2><p>Якщо Ви хочете <b>виконати запит даних у Вашому скрипті, в crontab тощо </b> додати параметр <code><u>&token_auth=%s</u></code> до URL API-запиту який вимагає ідентифікації.</p><p><b>Ніколи і нікому не повідомляйте</b> параметр token_auth, як і ваш логін чи пароль!</p>',
	'API_LoadedAPIs' => '%s API успішно завантажено',
	'Actions_SubmenuPages' => 'Сторінки',
	'Actions_SubmenuOutlinks' => 'Зовнішні посилання',
	'Actions_SubmenuDownloads' => 'Завантаження',
	'Actions_Actions' => 'Дії',
	'Actions_ColumnClicks' => 'Клацання',
	'Actions_ColumnUniqueClicks' => 'Унікальні клацання',
	'Actions_ColumnDownloads' => 'Завантаження',
	'Actions_ColumnUniqueDownloads' => 'Унікальні завантаження',
	'CoreHome_NoPrivileges' => 'Ви успішно представлені системі як \'%s\', але у вас немає жодник прав встановлених в Piwik.<br/>Зверніться до Вашого Piwik-адміністратора з проханням надати Вам право "перегляд".',
	'CoreHome_JavascriptDisabled' => 'Для користування Piwik в нормальному режимі, JavaScript у Вашому браузері має бути доступним.<br/>Однак JavaScript деактивований або недоступний у Вашому браузері.<br>Щоб користуватися Piwik в нормальному режимі, будь ласка активуйте JavaScript (це можна зробити в опціях браузера), після чого %1sспробуйте знову%2s.<br/>',
	'CoreHome_TableNoData' => 'Для цієї таблиці немає даних',
	'CoreHome_CategoryNoData' => 'В цій категорії немає даних. Спробуйте "Виключити всі групи людей"',
	'CoreHome_ShowJSCode' => 'Показати код вставки javascript',
	'CoreHome_IncludeAllPopulation_js' => 'Включити всі групи людей',
	'CoreHome_ExcludeLowPopulation_js' => 'Виключити малочисельні групи людей',
	'CoreHome_PageOf_js' => '%s із %s',
	'CoreHome_Loading_js' => 'Завантаження...',
	'CoreHome_LocalizedDateFormat' => '%A %d %B %Y',
	'CoreHome_PeriodDay' => 'День',
	'CoreHome_PeriodWeek' => 'Тиждень',
	'CoreHome_PeriodMonth' => 'Місяць',
	'CoreHome_PeriodYear' => 'Рік',
	'CoreHome_DaySu_js' => 'Нд',
	'CoreHome_DayMo_js' => 'Пн',
	'CoreHome_DayTu_js' => 'Вт',
	'CoreHome_DayWe_js' => 'Ср',
	'CoreHome_DayTh_js' => 'Чт',
	'CoreHome_DayFr_js' => 'Пт',
	'CoreHome_DaySa_js' => 'Сб',
	'CoreHome_ShortDay_1_js' => 'нед',
	'CoreHome_ShortDay_2_js' => 'пнд',
	'CoreHome_ShortDay_3_js' => 'вів',
	'CoreHome_ShortDay_4_js' => 'срд',
	'CoreHome_ShortDay_5_js' => 'чтв',
	'CoreHome_ShortDay_6_js' => 'птн',
	'CoreHome_ShortDay_7_js' => 'сбт',
	'CoreHome_LongDay_1_js' => 'неділя',
	'CoreHome_LongDay_2_js' => 'понеділок',
	'CoreHome_LongDay_3_js' => 'вівторок',
	'CoreHome_LongDay_4_js' => 'середа',
	'CoreHome_LongDay_5_js' => 'четвер',
	'CoreHome_LongDay_6_js' => 'п’ятниця',
	'CoreHome_LongDay_7_js' => 'субота',
	'CoreHome_ShortMonth_1_js' => 'Січ',
	'CoreHome_ShortMonth_2_js' => 'Лют',
	'CoreHome_ShortMonth_3_js' => 'Бер',
	'CoreHome_ShortMonth_4_js' => 'Кві',
	'CoreHome_ShortMonth_5_js' => 'Тра',
	'CoreHome_ShortMonth_6_js' => 'Чер',
	'CoreHome_ShortMonth_7_js' => 'Лип',
	'CoreHome_ShortMonth_8_js' => 'Сер',
	'CoreHome_ShortMonth_9_js' => 'Вер',
	'CoreHome_ShortMonth_10_js' => 'Жов',
	'CoreHome_ShortMonth_11_js' => 'Лис',
	'CoreHome_ShortMonth_12_js' => 'Гру',
	'CoreHome_MonthJanuary_js' => 'Січень',
	'CoreHome_MonthFebruary_js' => 'Лютий',
	'CoreHome_MonthMarch_js' => 'Березень',
	'CoreHome_MonthApril_js' => 'Квітень',
	'CoreHome_MonthMay_js' => 'Травень',
	'CoreHome_MonthJune_js' => 'Червень',
	'CoreHome_MonthJuly_js' => 'Липень',
	'CoreHome_MonthAugust_js' => 'Серпень',
	'CoreHome_MonthSeptember_js' => 'Вересень',
	'CoreHome_MonthOctober_js' => 'Жовтень',
	'CoreHome_MonthNovember_js' => 'Листопад',
	'CoreHome_MonthDecember_js' => 'Грудень',
	'CoreHome_PeriodDays' => 'днів',
	'CoreHome_PeriodWeeks' => 'тижнів',
	'CoreHome_PeriodMonths' => 'місяців',
	'CoreHome_PeriodYears' => 'років',
	'CorePluginsAdmin_Plugins' => 'Плагіни',
	'CorePluginsAdmin_Activated' => 'Активовано',
	'CorePluginsAdmin_ActivatedHelp' => 'Цей плагін не може бути деактивовано',
	'CorePluginsAdmin_Deactivate' => 'Деактивувати',
	'CorePluginsAdmin_Activate' => 'Активувати',
	'CorePluginsAdmin_MenuPlugins' => 'Плагіни',
	'CorePluginsAdmin_PluginsManagement' => 'Керування плагінами',
	'CorePluginsAdmin_MainDescription' => 'Plugins extend and expand the functionality of Piwik.
Плагіни розширюють та примножують функціонал Piwik. Як тільки плагін встановлено його можна автивувати або деактивувати тут.',
	'CorePluginsAdmin_Plugin' => 'Плагін',
	'CorePluginsAdmin_Version' => 'Версія',
	'CorePluginsAdmin_Description' => 'Опис',
	'CorePluginsAdmin_Status' => 'Статус',
	'CorePluginsAdmin_Action' => 'Дія',
	'CorePluginsAdmin_PluginHomepage' => 'Домашня сторінка плагіна',
	'CorePluginsAdmin_Active' => 'Активний',
	'CorePluginsAdmin_Inactive' => 'Неактивний',
	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; Поновлення',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Необхідно поновити базу даних',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'База даних Piwik застаріла, і повинна бути поновлена перед наступним кроком.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'База даних Piwik буде поновлена з версії %s до нової версії %s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Наступні плагіни буде поновлено: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Процес поновлення бази даних може забрати трохи часу, зачекайте будь-ласка.',
	'CoreUpdater_UpgradePiwik' => 'Поновити Piwik',
	'CoreUpdater_HelpMessageContent' => 'Гляньте на %s Piwik FAQ %s де є пояснення найтиповіших помилок що виникають протягом поновлення. %s Зверніться за допомогою до системного адміністратора, - що може допомогти вирішити помилки пов’язані з сервером або налаштуванням бази даних.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Критична помилка протягом процесу поновлення:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Вище знаходиться повідомлення про помилку рівня ядра. Це повинно допомогти у виявлення причини, але якщо потрібна подальша допомога, будьласка:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Поновлення завершено успішно, однак були інциденти протягом проходження процесу. Будь-ласка прочитайте опис щоб дізнатися деталі. Для подальшої допомоги:',
	'CoreUpdater_UpgradeComplete' => 'Поновлення завершено!',
	'CoreUpdater_WarningMessages' => 'Застережні повідомлення:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Помилка протягом поновлення плагіну:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Автоматично деактивовано наступні плагіни: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik успішно поновлено!',
	'CoreUpdater_ContinueToPiwik' => 'Перейти далі до Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Поновити автоматично',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Є нова версія Piwik доступна до поновлення',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Можна поновити до версії %s автоматично або завантажити пакунок та встановити в ручну:',
	'CoreUpdater_DownloadX' => 'Завантажити %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Поновлення Piwik Одним Клацанням було скасовано. Якщо неможливо виправити повідомлення про помилку вище, рекомендується поновити Piwik вручну. %s Гляньте %sДокументацію про поновлення%s щоб розпочати!',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Перевірка розпакованих файлів',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Створення резервної копії файлів конфігурції в %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Встановлення останньої версії',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik успішно поновлено!',
	'DBStats_DatabaseUsage' => 'Використання бази даних',
	'DBStats_MainDescription' => 'Piwik зберігає всі дані для веб-аналітики в MySQL базі даних. На даний час, таблиці з даними Piwik займають %s',
	'DBStats_Table' => 'Таблиця',
	'DBStats_RowNumber' => 'Номер рядка',
	'DBStats_DataSize' => 'Розмір даних',
	'DBStats_IndexSize' => 'Розмір індексів',
	'DBStats_TotalSize' => 'Розмір таблиці',
	'Dashboard_AddWidget' => 'Додати віджет...',
	'Dashboard_DeleteWidgetConfirm' => 'Видалити цей віджет з центру керування?',
	'Dashboard_SelectWidget' => 'Оберіть віджет для розміщення в центрі керування',
	'Dashboard_AddPreviewedWidget' => 'Додати попередньо переглянутий віджет до центру керування',
	'Dashboard_WidgetPreview' => 'Попередній перегляд віджета',
	'Dashboard_TitleWidgetInDashboard_js' => 'Віджет вже розміщено в центрі керування',
	'Dashboard_TitleClickToAdd_js' => 'Клацніть щоб розмістити в центрі керування',
	'Dashboard_LoadingPreview_js' => 'Підготовка попереднього перегляду, зачекайте...',
	'Dashboard_LoadingWidget_js' => 'Завантаження віджету, зачекайте...',
	'Dashboard_WidgetNotFound_js' => 'Віджет не знайдено',
	'Dashboard_Dashboard' => 'Центр керування',
	'ExamplePlugin_exampleWidget' => 'Зразок віджету',
	'ExamplePlugin_blogPiwikRss' => 'RSS з Piwik блогу',
	'ExamplePlugin_photostreamMatt' => 'Фотки Метта',
	'Installation_Installation' => 'Встановлення',
	'Installation_InstallationStatus' => 'Статус встановлення',
	'Installation_PercentDone' => '%s %% Завершено',
	'Installation_NoConfigFound' => 'Файл конфігурації Piwik не знайдено в той час як Ви намагаєтесь користуватися Piwik.<br><b>&nbsp;&nbsp;&raquo; Ви можете <a href=\'index.php\'>встановити Piwik зараз</a></b><br><small>Якщо ви встановили Piwik раніше і деякі таблиці залишились в базі даних, Ви зможете використати їх і тим самим зберегти вже існуючі дані!</small>',
	'Installation_MysqlSetup' => 'Налаштування бази даних Mysql',
	'Installation_MysqlErrorConnect' => 'Виникла помилка при спробі під’єднання до бази даних Mysql',
	'Installation_JsTag' => 'Тег JavaScript',
	'Installation_JsTagHelp' => '<p>Щоб отримати статистику для всіх відвідувачів, необхідно вставити JavaScript код на всі Ваші сторінки.</p><p>Немає необхідності в тому, щоб Ваші стрінки були написані на PHP. Piwik буде працювати з будь-якими сторінками (написаними на HTML, ASP, Perl або інших мовах).</p><p>Ось JavaScript код для вставки: (вставте в кожну Вашу сторінку) </p>',
	'Installation_Congratulations' => 'Вітання!',
	'Installation_CongratulationsHelp' => '<p>Вітання! Встановлення Piwik завершено.</p><p>Переконайтеся що JavaScript код додано на кожну вашу сторінку, та очікуйте на перших відвідувачів!</p>',
	'Installation_GoToPiwik' => 'Перейти до Piwik',
	'Installation_SetupWebsite' => 'Налаштувати веб-сайт',
	'Installation_SetupWebsiteError' => 'Виникла помилка при додаванні веб-сайту',
	'Installation_GeneralSetup' => 'Загальне Налаштування',
	'Installation_GeneralSetupSuccess' => 'Загальне Налаштування успішно виконано',
	'Installation_SystemCheck' => 'Перевірка системи',
	'Installation_SystemCheckPhp' => 'Версія PHP',
	'Installation_SystemCheckPdo' => 'Розширення Pdo',
	'Installation_SystemCheckPdoMysql' => 'Розширення Pdo_Mysql',
	'Installation_SystemCheckPdoError' => 'Необхідно активувати PDO та PDO_MYSQL розширення в php.ini файлі.',
	'Installation_SystemCheckPdoHelp' => 'На сервері Windows Ви можете додати наступні рядки у php.ini файл: %s <br><br>На Linux сервері необхідно скомпілювати php з наступними опціями: %s У php.ini додайте наступні строки: %s<br><br>Докладніше на  <a style="color:red" href="http://php.net/pdo">сайті PHP</a>.',
	'Installation_SystemCheckWriteDirs' => 'Директорії з доступом на запис',
	'Installation_SystemCheckWriteDirsHelp' => 'Щоб вирішити цю проблему на Linux системі, спробуйте ввести наступні команду(-и)',
	'Installation_SystemCheckMemoryLimit' => 'Граничний розмір пам\'яті',
	'Installation_SystemCheckMemoryLimitHelp' => 'На сайті з високим трафіком процес стистення даних може потребувати більше пам\'яті ніж дозволено зараз.<br/>Дивіться детальніше про директиву memory_limit у файлі php.ini.',
	'Installation_SystemCheckGD' => 'GD &gt; 2.x (графіка)',
	'Installation_SystemCheckGDHelp' => 'Міні-графіки не будуть відображатися.',
	'Installation_SystemCheckTimeLimit' => 'функція set_time_limit() доступна',
	'Installation_SystemCheckTimeLimitHelp' => 'На сайті з високим трафіком процес стистення даних може потребувати більше часу ніж доступно зараз в налаштуваннях PHP.<br/>Дивіться детальніше про директиву max_execution_time у Вашому файлі php.ini.',
	'Installation_SystemCheckMail' => 'функція mail() доступна',
	'Installation_SystemCheckError' => 'Виникла помилка - треба виправити перед тим як рухатись далі',
	'Installation_SystemCheckWarning' => 'Piwik буде працювати за вийнятком деяких можливостей',
	'Installation_Tables' => 'Стровення таблиць',
	'Installation_TablesWarning' => 'Деякі <span id="linkToggle">таблиці Piwik</span> вже установлені в базі даних',
	'Installation_TablesFound' => 'Наступні таблиці знайдено в базі даних',
	'Installation_TablesWarningHelp' => 'Оберіть, чи хочете Ви використати існуючі таблиці, або виберіть установку "з нуля", щоб видалити всі існуючі таблиці в базі даних',
	'Installation_TablesReuse' => 'Використати існуючі таблиці',
	'Installation_TablesDelete' => 'Видалити знайдені таблиці',
	'Installation_TablesDeletedSuccess' => 'Існуючі таблиці Piwik видалено успішно',
	'Installation_TablesCreatedSuccess' => 'Таблиці створено успішно!',
	'Installation_TablesDeleteConfirm' => 'Ви впевнені, що хочете видалити всі таблиці Piwik з бази даних?',
	'Installation_Welcome' => 'Вітання!',
	'Installation_WelcomeHelp' => '<p>Piwik - це <a href="http://ru.wikipedia.org/wiki/Open_source">open source</a> програмне забезпечення для веб-аналітики, за допомогою якого ви можете з легкісню отримати аналітичну інформацию про ваших відвідувачів.</p><p>Цей процес складається з %s простих кроків і займе не більше 5 хвилин.</p>',
	'Installation_ContinueToPiwik' => 'Перейти далі до Piwik',
	'Installation_SuperUserLogin' => 'логін супер-користувача',
	'Installation_Password' => 'пароль',
	'Installation_PasswordRepeat' => 'пароль (повторно)',
	'Installation_Email' => 'е-майл',
	'Installation_SecurityNewsletter' => 'Надішліть повідомлення при виході нових версій Piwik та поновленнях безпеки',
	'Installation_CommunityNewsletter' => 'Надішліть повідомлення з поновленнями від спільноти (нові плагіни, нові переваги, і т. д.)',
	'Installation_PasswordDoNotMatch' => 'пароль не співпадає',
	'Installation_SubmitGo' => 'Вперед!',
	'Installation_TablesWithSameNamesFound' => 'Деякі %s таблиці в базі даних %s мають імена тих таблиць що створюються Piwik-ом.',
	'Installation_DatabaseCreatedSuccess' => 'Базу даних %s створено успішно!',
	'Installation_GoBackAndDefinePrefix' => 'Повернутися і встановити префікс для таблиць Piwik',
	'Installation_ConfirmDeleteExistingTables' => 'Впевнені що хочете видалити таблиці: %s з бази даних?
ЗАСТЕРЕЖЕННЯ: ДАНІ З ЦИХ ТАБЛИЦЬ НЕМОЖУТЬ БУТИ ВІДНОВЛЕНІ!',
	'Installation_ErrorInvalidState' => 'Помилка: здається була спроба пропустити крок процесу встановлення, або браузер не приймає куки, або файл конфігурації Piwik вже створено. %sПереконайтеся що куки дозволено%s та поверніться %s до першого кроку процесу встановлення %s.',
	'Login_LoginPasswordNotCorrect' => 'Ім\'я користувача та пароль невірні',
	'Login_Login' => 'Ім\'я користувача',
	'Login_Password' => 'Пароль',
	'Login_LoginOrEmail' => 'Ім\'я користувача або E-mail',
	'Login_LogIn' => 'Увійти',
	'Login_Logout' => 'Вийти',
	'Login_LostYourPassword' => 'Забули свій пароль?',
	'Login_RemindPassword' => 'Нагадати пароль',
	'Login_PasswordReminder' => 'Будь ласка, вкажіть ваші Ім\'я користувача або E-mail. Ви отримаєте новий пароль на Ваш e-mail.',
	'Login_InvalidUsernameEmail' => 'Невірне Ім\'я користувача та/або E-mail',
	'Login_MailTopicPasswordRecovery' => 'Відновлення пароля',
	'Login_MailPasswordRecoveryBody' => 'Вітаю, %1s\n\n Ваш новий пароль: %2s\n\n Тепер ви можете зайти в систему тут: %3s',
	'Login_PasswordSent' => 'Пароль було надіслано. Перевірте ваш e-mail.',
	'Login_ContactAdmin' => 'Можлива причина: функція mail() відключена в налаштуваннях вашого хостингу.<br/>Зверніться, будь ласка, до вашого Piwik-адміністратора.',
	'Provider_WidgetProviders' => 'Провайдери',
	'Provider_SubmenuLocationsProvider' => 'Місцезнаходження та провайдери',
	'Referers_SearchEngines' => 'Пошукові системи',
	'Referers_Keywords' => 'Ключові слова',
	'Referers_DirectEntry' => 'Прямі заходження',
	'Referers_Websites' => 'Веб-сайти',
	'Referers_Newsletters' => 'Листи Новин',
	'Referers_Campaigns' => 'Кампанії',
	'Referers_Evolution' => 'Динаміка протягом періоду',
	'Referers_Type' => 'Тип реферера',
	'Referers_TypeDirectEntries' => '%s прямих заходжень',
	'Referers_TypeSearchEngines' => '%s з пошукових систем',
	'Referers_TypeWebsites' => '%s з веб-сайтів',
	'Referers_TypeNewsletters' => '%s з листів новин',
	'Referers_TypeCampaigns' => '%s з кампаній',
	'Referers_Other' => 'Інше',
	'Referers_OtherDistinctSearchEngines' => '%s унікальних пошукових систем',
	'Referers_OtherDistinctKeywords' => '%s унікальних ключових слів',
	'Referers_OtherDistinctWebsites' => '%1s унікальних вебсайтів (використовуючи %2s унікальних URL-адрес)',
	'Referers_OtherDistinctCampaigns' => '%s унікальних кампаній',
	'Referers_TagCloud' => 'Ярлики',
	'Referers_SubmenuEvolution' => 'Динаміка',
	'Referers_SubmenuSearchEngines' => 'Пошукові системи і ключові слова',
	'Referers_SubmenuWebsites' => 'Веб-сайти',
	'Referers_SubmenuCampaigns' => 'Кампанії',
	'Referers_WidgetKeywords' => 'Список ключових слів',
	'Referers_WidgetCampaigns' => 'Список кампаній',
	'Referers_WidgetExternalWebsites' => 'Список зовнішніх веб-сайтів',
	'Referers_WidgetSearchEngines' => 'Кращі пошукові системи',
	'Referers_WidgetOverview' => 'Огляд',
	'Referers_Referers' => 'Реферер',
	'Referers_DetailsByRefererType' => 'Деталі по типу реферера',
	'SitesManager_Sites' => 'Сайти',
	'SitesManager_JsCode' => 'Код JavaScript',
	'SitesManager_JsCodeHelp' => 'Ось код JavaScript щоб додати на кожну сторінку',
	'SitesManager_ShowJsCode' => 'показати код',
	'SitesManager_NoWebsites' => 'Немає жодного сайту щоб адмініструвати',
	'SitesManager_AddSite' => 'Додати новий сайт',
	'SitesManager_Id' => 'Id',
	'SitesManager_Name' => 'Назва',
	'SitesManager_Urls' => 'URL-адреси',
	'SitesManager_MenuSites' => 'Сайти',
	'SitesManager_DeleteConfirm_js' => 'Видалити веб-сайт %s?',
	'SitesManager_ExceptionDeleteSite' => 'Неможливо видалити цей сайт, так як це єдиний зареєстрований сайт. Додайте новий сайт, і після цього ви отримаєте можливість видалити цей.',
	'SitesManager_ExceptionNoUrl' => 'Ви маєте вказати хоча б одину URL-адресу для сайту.',
	'SitesManager_ExceptionEmptyName' => 'Ім\'я сайту не може бути порожнім.',
	'SitesManager_ExceptionInvalidUrl' => 'URL-адреса невірна: "%s".',
	'SitesManager_WebsitesManagement' => 'Керування веб-сайтами',
	'SitesManager_MainDescription' => 'Звіти з веб-аналітики потребують веб-сайтів! Додайте, поновіть, видаліть веб-сайти, та отримайте JavaScript-код щоб додати на свої сторіки.',
	'TranslationsAdmin_MenuTranslations' => 'Переклади',
	'TranslationsAdmin_MenuLanguages' => 'Мови',
	'TranslationsAdmin_Plugin' => 'Плагін',
	'TranslationsAdmin_Definition' => 'Означення',
	'TranslationsAdmin_DefaultString' => 'Типовий рядок (Англійською)',
	'TranslationsAdmin_TranslationString' => 'Рядок перекладу<br/>(поточна мова: %s)',
	'TranslationsAdmin_Translations' => 'Переклади',
	'TranslationsAdmin_FixPermissions' => 'Будь ласка, встановіть відповідні права доступу до файлів',
	'TranslationsAdmin_AvailableLanguages' => 'Доступні мови',
	'TranslationsAdmin_AddLanguage' => 'Додати мову',
	'TranslationsAdmin_LanguageCode' => 'Код мови',
	'TranslationsAdmin_Export' => 'Експортувати мову',
	'TranslationsAdmin_Import' => 'Імпортувати мову',
	'UserCountry_Country' => 'Країна',
	'UserCountry_Continent' => 'Континент',
	'UserCountry_DistinctCountries' => '%s унікальних країн',
	'UserCountry_SubmenuLocations' => 'Місцезнаходження',
	'UserCountry_WidgetContinents' => 'Континенти відвідувачів',
	'UserCountry_WidgetCountries' => 'Країни відвідувачів',
	'UserCountry_country_ac' => 'Острів Вознесіння',
	'UserCountry_country_ad' => 'Андорра',
	'UserCountry_country_ae' => 'Об\'єднані Арабські Емірати',
	'UserCountry_country_af' => 'Афганістан',
	'UserCountry_country_ag' => 'Антигуа і Барбуда',
	'UserCountry_country_ai' => 'Ангілья',
	'UserCountry_country_al' => 'Албанія',
	'UserCountry_country_am' => 'Вірменія',
	'UserCountry_country_an' => 'Нідерландські Антильські острови',
	'UserCountry_country_ao' => 'Ангола',
	'UserCountry_country_aq' => 'Антарктида',
	'UserCountry_country_ar' => 'Аргентина',
	'UserCountry_country_as' => 'Східне Самоа',
	'UserCountry_country_at' => 'Австрія',
	'UserCountry_country_au' => 'Австралійський Союз',
	'UserCountry_country_aw' => 'Аруба',
	'UserCountry_country_az' => 'Азербайджан',
	'UserCountry_country_ba' => 'Боснія і Герцеґовина',
	'UserCountry_country_bb' => 'Барбадос',
	'UserCountry_country_bd' => 'Бангладеш',
	'UserCountry_country_be' => 'Бельгія',
	'UserCountry_country_bf' => 'Буркіна-Фасо',
	'UserCountry_country_bg' => 'Болгарія',
	'UserCountry_country_bh' => 'Бахрейн',
	'UserCountry_country_bi' => 'Бурунді',
	'UserCountry_country_bj' => 'Бенін',
	'UserCountry_country_bm' => 'Бермудські острови',
	'UserCountry_country_bn' => 'Брунео',
	'UserCountry_country_bo' => 'Болівія',
	'UserCountry_country_br' => 'Бразилія',
	'UserCountry_country_bs' => 'Багамські Острови',
	'UserCountry_country_bt' => 'Бутан',
	'UserCountry_country_bv' => 'Буве',
	'UserCountry_country_bw' => 'Ботсвана',
	'UserCountry_country_by' => 'Білорусь',
	'UserCountry_country_bz' => 'Беліз',
	'UserCountry_country_ca' => 'Канада',
	'UserCountry_country_cc' => 'Кокосові Острови',
	'UserCountry_country_cd' => 'Демократична Республіка Конго',
	'UserCountry_country_cf' => 'Центрально-Африканська Республіка',
	'UserCountry_country_cg' => 'Конго',
	'UserCountry_country_ch' => 'Швейцарія',
	'UserCountry_country_ci' => 'Кот-д\'Івуар',
	'UserCountry_country_ck' => 'Острови Кука',
	'UserCountry_country_cl' => 'Чилі',
	'UserCountry_country_cm' => 'Камерун',
	'UserCountry_country_cn' => 'Китай ',
	'UserCountry_country_co' => 'Колумбія',
	'UserCountry_country_cr' => 'Коста-Ріка',
	'UserCountry_country_cs' => 'Сербія і Чорногорія',
	'UserCountry_country_cu' => 'Куба',
	'UserCountry_country_cv' => 'Кабо-Верде',
	'UserCountry_country_cx' => 'Острів Різдва',
	'UserCountry_country_cy' => 'Кіпр',
	'UserCountry_country_cz' => 'Чехія',
	'UserCountry_country_de' => 'Німеччина',
	'UserCountry_country_dj' => 'Джибуті',
	'UserCountry_country_dk' => 'Данія',
	'UserCountry_country_dm' => 'Домініка',
	'UserCountry_country_do' => 'Домініканська Республіка',
	'UserCountry_country_dz' => 'Алжир',
	'UserCountry_country_ec' => 'Еквадор',
	'UserCountry_country_ee' => 'Естонія',
	'UserCountry_country_eg' => 'Єгипет',
	'UserCountry_country_eh' => 'Західна Сахара',
	'UserCountry_country_er' => 'Еритрея',
	'UserCountry_country_es' => 'Іспанія',
	'UserCountry_country_et' => 'Ефіопія',
	'UserCountry_country_fi' => 'Фінляндія',
	'UserCountry_country_fj' => 'Фіджі',
	'UserCountry_country_fk' => 'Фолклендські острови',
	'UserCountry_country_fm' => 'Федеративні Штати Мікронезії',
	'UserCountry_country_fo' => 'Фарерські острови',
	'UserCountry_country_fr' => 'Франція',
	'UserCountry_country_ga' => 'Габон',
	'UserCountry_country_gd' => 'Гренада',
	'UserCountry_country_ge' => 'Грузія',
	'UserCountry_country_gf' => 'Французька Гвіана',
	'UserCountry_country_gg' => 'Гернсі',
	'UserCountry_country_gh' => 'Гана',
	'UserCountry_country_gi' => 'Гібралтар',
	'UserCountry_country_gl' => 'Ґренландія',
	'UserCountry_country_gm' => 'Гамбія',
	'UserCountry_country_gn' => 'Гвінея',
	'UserCountry_country_gp' => 'Гваделупа',
	'UserCountry_country_gq' => 'Екваторіальна Гвінея',
	'UserCountry_country_gr' => 'Греція',
	'UserCountry_country_gs' => 'Південна Джорджія та Південні Сандвічеві острови',
	'UserCountry_country_gt' => 'Гватемала',
	'UserCountry_country_gu' => 'Гуам',
	'UserCountry_country_gw' => 'Гвінея-Бісау',
	'UserCountry_country_gy' => 'Гаяна',
	'UserCountry_country_hk' => 'Гонконґ',
	'UserCountry_country_hm' => 'Острів Херд та Острови Макдоналд',
	'UserCountry_country_hn' => 'Гондурас',
	'UserCountry_country_hr' => 'Хорватія',
	'UserCountry_country_ht' => 'Гаїті',
	'UserCountry_country_hu' => 'Угорщина',
	'UserCountry_country_id' => 'Індонезія',
	'UserCountry_country_ie' => 'Ірландія (острів)',
	'UserCountry_country_il' => 'Ізраїль',
	'UserCountry_country_im' => 'Man Island',
	'UserCountry_country_in' => 'Індія',
	'UserCountry_country_io' => 'Британська територія в Індійському океані',
	'UserCountry_country_iq' => 'Ірак',
	'UserCountry_country_ir' => 'Іран',
	'UserCountry_country_is' => 'Ісландія',
	'UserCountry_country_it' => 'Італія',
	'UserCountry_country_je' => 'Джерсі (острів)',
	'UserCountry_country_jm' => 'Ямайка',
	'UserCountry_country_jo' => 'Йорданія',
	'UserCountry_country_jp' => 'Японія',
	'UserCountry_country_ke' => 'Кенія',
	'UserCountry_country_kg' => 'Киргизстан',
	'UserCountry_country_kh' => 'Камбоджа',
	'UserCountry_country_ki' => 'Кірібаті',
	'UserCountry_country_km' => 'Коморські Острови',
	'UserCountry_country_kn' => 'Сент-Кітс і Невіс',
	'UserCountry_country_kp' => 'Північна Корея',
	'UserCountry_country_kr' => 'Південна Корея',
	'UserCountry_country_kw' => 'Кувейт',
	'UserCountry_country_ky' => 'Кайманові острови',
	'UserCountry_country_kz' => 'Казахстан',
	'UserCountry_country_la' => 'Лаос',
	'UserCountry_country_lb' => 'Ліван',
	'UserCountry_country_lc' => 'Сент-Люсія',
	'UserCountry_country_li' => 'Ліхтенштейн',
	'UserCountry_country_lk' => 'Шрі-Ланка',
	'UserCountry_country_lr' => 'Ліберія',
	'UserCountry_country_ls' => 'Лесото',
	'UserCountry_country_lt' => 'Литва',
	'UserCountry_country_lu' => 'Люксембург',
	'UserCountry_country_lv' => 'Латвія',
	'UserCountry_country_ly' => 'Лівія',
	'UserCountry_country_ma' => 'Марокко',
	'UserCountry_country_mc' => 'Монако',
	'UserCountry_country_md' => 'Молдова',
	'UserCountry_country_mg' => 'Мадагаскар',
	'UserCountry_country_mh' => 'Маршаллові Острови',
	'UserCountry_country_mk' => 'Македонія',
	'UserCountry_country_ml' => 'Малі',
	'UserCountry_country_mm' => 'М\'янма',
	'UserCountry_country_mn' => 'Монголія',
	'UserCountry_country_mo' => 'Макао ',
	'UserCountry_country_mp' => 'Північні Маріанські острови',
	'UserCountry_country_mq' => 'Мартиніка',
	'UserCountry_country_mr' => 'Мавританія',
	'UserCountry_country_ms' => 'Монтсеррат',
	'UserCountry_country_mt' => 'Мальта',
	'UserCountry_country_mu' => 'Маврикій',
	'UserCountry_country_mv' => 'Мальдіви',
	'UserCountry_country_mw' => 'Малаві',
	'UserCountry_country_mx' => 'Мексика',
	'UserCountry_country_my' => 'Малайзія',
	'UserCountry_country_mz' => 'Мозамбік',
	'UserCountry_country_na' => 'Намібія',
	'UserCountry_country_nc' => 'Нова Каледонія',
	'UserCountry_country_ne' => 'Нігер',
	'UserCountry_country_nf' => 'Острів Норфолк',
	'UserCountry_country_ng' => 'Нігерія',
	'UserCountry_country_ni' => 'Нікарагуа',
	'UserCountry_country_nl' => 'Нідерланди',
	'UserCountry_country_no' => 'Норвегія',
	'UserCountry_country_np' => 'Непал',
	'UserCountry_country_nr' => 'Науру',
	'UserCountry_country_nu' => 'Ніуе',
	'UserCountry_country_nz' => 'Нова Зеландія',
	'UserCountry_country_om' => 'Оман',
	'UserCountry_country_pa' => 'Панама',
	'UserCountry_country_pe' => 'Перу',
	'UserCountry_country_pf' => 'Французька Полінезія',
	'UserCountry_country_pg' => 'Папуа-Нова Гвінея',
	'UserCountry_country_ph' => 'Філіппіни',
	'UserCountry_country_pk' => 'Пакистан',
	'UserCountry_country_pl' => 'Польща',
	'UserCountry_country_pm' => 'Сен-П\'єр і Мікелон',
	'UserCountry_country_pn' => 'Піткерн',
	'UserCountry_country_pr' => 'Пуерто-Ріко',
	'UserCountry_country_ps' => 'Палестинська Територія',
	'UserCountry_country_pt' => 'Португалія',
	'UserCountry_country_pw' => 'Палау',
	'UserCountry_country_py' => 'Парагвай',
	'UserCountry_country_qa' => 'Катар',
	'UserCountry_country_re' => 'Реюньйон',
	'UserCountry_country_ro' => 'Румунія',
	'UserCountry_country_rw' => 'Руанда',
	'UserCountry_country_sa' => 'Саудівська Аравія',
	'UserCountry_country_sb' => 'Соломонові Острови',
	'UserCountry_country_sc' => 'Сейшельські Острови',
	'UserCountry_country_sd' => 'Судан',
	'UserCountry_country_se' => 'Швеція',
	'UserCountry_country_sg' => 'Сингапур',
	'UserCountry_country_sh' => 'Острів Святої Єлени',
	'UserCountry_country_si' => 'Словенія',
	'UserCountry_country_sj' => 'Свальбард',
	'UserCountry_country_sk' => 'Словаччина',
	'UserCountry_country_sl' => 'Сьєрра-Леоне',
	'UserCountry_country_sm' => 'Сан-Марино',
	'UserCountry_country_sn' => 'Сенегал',
	'UserCountry_country_so' => 'Сомалі',
	'UserCountry_country_sr' => 'Суринам',
	'UserCountry_country_st' => 'Сан-Томе і Прінсіпі',
	'UserCountry_country_su' => 'старий СРСР',
	'UserCountry_country_sv' => 'Сальвадор',
	'UserCountry_country_sy' => 'Сирія',
	'UserCountry_country_sz' => 'Свазіленд',
	'UserCountry_country_tc' => 'Острови Теркс і Кайкос',
	'UserCountry_country_td' => 'Чад',
	'UserCountry_country_tf' => 'Французькі Південні й Антарктичні Території',
	'UserCountry_country_tg' => 'Того',
	'UserCountry_country_th' => 'Таїланд',
	'UserCountry_country_tj' => 'Таджикистан',
	'UserCountry_country_tk' => 'Токелау',
	'UserCountry_country_tm' => 'Туркменістан',
	'UserCountry_country_tn' => 'Туніс',
	'UserCountry_country_to' => 'Тонга',
	'UserCountry_country_tp' => 'Східний Тимор',
	'UserCountry_country_tr' => 'Туреччина',
	'UserCountry_country_tt' => 'Тринідад і Тобаго',
	'UserCountry_country_tv' => 'Тувалу',
	'UserCountry_country_tw' => 'Тайвань',
	'UserCountry_country_tz' => 'Танзанія',
	'UserCountry_country_ua' => 'Україна',
	'UserCountry_country_ug' => 'Уганда',
	'UserCountry_country_uk' => 'Велика Британія',
	'UserCountry_country_gb' => 'Великобританія (острів)',
	'UserCountry_country_um' => 'Зовнішні малі острови (США)',
	'UserCountry_country_us' => 'Сполучені Штати Америки',
	'UserCountry_country_uy' => 'Уругвай',
	'UserCountry_country_uz' => 'Узбекистан',
	'UserCountry_country_va' => 'Ватикан',
	'UserCountry_country_vc' => 'Сент-Вінсент і Гренадини',
	'UserCountry_country_ve' => 'Венесуела',
	'UserCountry_country_vg' => 'Британські Віргінські острови',
	'UserCountry_country_vi' => 'Американські Віргінські острови',
	'UserCountry_country_vn' => 'В\'єтнам',
	'UserCountry_country_vu' => 'Вануату',
	'UserCountry_country_wf' => 'Волліс і Футуна',
	'UserCountry_country_ws' => 'Самоа',
	'UserCountry_country_ye' => 'Ємен',
	'UserCountry_country_yt' => 'Майотта',
	'UserCountry_country_yu' => 'Югославія',
	'UserCountry_country_za' => 'Південно-Африканська Республіка',
	'UserCountry_country_zm' => 'Замбія',
	'UserCountry_country_zr' => 'Заір',
	'UserCountry_country_zw' => 'Зімбабве',
	'UserCountry_continent_eur' => 'Європа',
	'UserCountry_continent_afr' => 'Африка',
	'UserCountry_continent_asi' => 'Азія',
	'UserCountry_continent_ams' => 'Південна та Центральна Америка',
	'UserCountry_continent_amn' => 'Північна америка',
	'UserCountry_continent_oce' => 'Океанія',
	'UserCountry_country_ax' => 'Аландські острови',
	'UserCountry_country_bl' => 'Сен-Бартельмі',
	'UserCountry_country_bu' => 'М\'янма',
	'UserCountry_country_cp' => 'Острів Кліппертон',
	'UserCountry_country_dg' => 'Дієго Гарсія',
	'UserCountry_country_ea' => 'Сеута, Мелілья',
	'UserCountry_country_eu' => 'Європейський Союз',
	'UserCountry_country_fx' => 'Метрополія Франції',
	'UserCountry_country_ic' => 'Канарські острови',
	'UserCountry_country_me' => 'Чорногорія',
	'UserCountry_country_mf' => 'Сан-Мартін',
	'UserCountry_country_nt' => 'Нейтральна зона',
	'UserCountry_country_ru' => 'Росія',
	'UserCountry_country_rs' => 'Сербія',
	'UserCountry_country_sf' => 'Фінляндія',
	'UserCountry_country_ta' => 'Трастан-да-Кунья',
	'UserCountry_country_tl' => 'Східний Тімор',
	'UserSettings_BrowserFamilies' => 'Категорії браузерів',
	'UserSettings_Browsers' => 'Браузери',
	'UserSettings_Plugins' => 'Плагіни',
	'UserSettings_Configurations' => 'Конфігурації',
	'UserSettings_OperatingSystems' => 'Операційні системи',
	'UserSettings_Resolutions' => 'Роздільні здатності',
	'UserSettings_WideScreen' => 'Широкоформатність',
	'UserSettings_WidgetResolutions' => 'Роздільні здатності',
	'UserSettings_WidgetBrowsers' => 'Браузери відвідувачів',
	'UserSettings_WidgetPlugins' => 'Список плагінів',
	'UserSettings_WidgetWidescreen' => 'Нормальний / Широкоформатний',
	'UserSettings_WidgetBrowserFamilies' => 'Браузери за категоріями',
	'UserSettings_WidgetOperatingSystems' => 'Операційні системи',
	'UserSettings_WidgetGlobalVisitors' => 'Загальна конфігурація відвідувачів',
	'UserSettings_SubmenuSettings' => 'Налаштування',
	'UsersManager_ManageAccess' => 'Управління доступом',
	'UsersManager_Sites' => 'Сайти',
	'UsersManager_AllWebsites' => 'Всі веб-сайти',
	'UsersManager_ApplyToAllWebsites' => 'Застосувати до всіх веб-сайтів',
	'UsersManager_User' => 'Користувачі',
	'UsersManager_PrivNone' => 'Без доступу',
	'UsersManager_PrivView' => 'Перегляд',
	'UsersManager_PrivAdmin' => 'Адміністрування',
	'UsersManager_ChangeAllConfirm' => 'Змінити права "%s" для всіх вебсайтів?',
	'UsersManager_Login' => 'Ім\'я користувача',
	'UsersManager_Password' => 'Пароль',
	'UsersManager_Email' => 'E-mail',
	'UsersManager_Alias' => 'Псевдонім',
	'UsersManager_Token' => 'token_auth (код авторизації)',
	'UsersManager_Edit' => 'Редагувати',
	'UsersManager_AddUser' => 'Створити нового користувача',
	'UsersManager_MenuUsers' => 'Користувачі',
	'UsersManager_DeleteConfirm_js' => 'Видалити користувача %s?',
	'UsersManager_ExceptionLoginExists' => 'Ім\'я користувача "%s" вже існує.',
	'UsersManager_ExceptionEmailExists' => 'Користувач з адресою e-mail "%s" вже існує.',
	'UsersManager_ExceptionInvalidPassword' => 'Пароль має бути довжиною від 6 до 26 символів.',
	'UsersManager_ExceptionInvalidEmail' => 'Невірний e-mail.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Користувач "%s" не існує і тому не може бути видалений.',
	'UsersManager_ExceptionAdminAnonymous' => 'Не можна надати права адміністратора анонімним користувачам.',
	'UsersManager_ExceptionEditAnonymous' => 'Анонімний користувач не може бути відредагований або видалений. Цей тип користувачів Piwik застосовує для користувачів, які не представились системі. Наприклад, Ви можете зробити Вашу статистику публічною надаючи права "перегляду" анонімномим користувачам.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Користувач "%s" не існує.',
	'UsersManager_ExceptionAccessValues' => 'Параметр доступу повинен мати одне з наступних значень: [ %s ]',
	'UsersManager_UsersManagement' => 'Керування Користувачами',
	'UsersManager_UsersManagementMainDescription' => 'Створіть нових користувачів або редагуйте існуючих. Також нижче можна задати права доступу для них.',
	'UsersManager_MainDescription' => 'Встановіть який рівень Piwik доступу має кожен користувач на ваших веб-сайтах.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Ім’я користувача повинно бути довжиною від %s до %s символів та містити тільки букви, цифри, символи "_", "-" та "."',
	'UsersManager_ExceptionSuperUser' => 'Запитуваний користувач є Супер-користувачем а тому не може бути запитаний, редогований або видалений через API. Можна тільки вручну редагувати деталі Супер-користувача в конфігураційному файлі Piwik.',
	'VisitFrequency_Evolution' => 'Динаміка протягом періоду',
	'VisitFrequency_ReturnVisits' => '%s повторних відвідувань',
	'VisitFrequency_ReturnActions' => '%s переглядів сторінок повторними відвідувачами',
	'VisitFrequency_ReturnMaxActions' => 'Максимум %s переглядів сторінок повторними відвідувачами',
	'VisitFrequency_ReturnTotalTime' => '%s сумарний час проведений повторними відвідувачами на сайті',
	'VisitFrequency_ReturnBounces' => '%s раз повторні відвідувачі залишили сайт після перегляду однієї сторінки',
	'VisitFrequency_WidgetOverview' => 'Огляд частоти',
	'VisitFrequency_WidgetGraphReturning' => 'Графік повторних відвідувань',
	'VisitFrequency_SubmenuFrequency' => 'Частота',
	'VisitTime_LocalTime' => 'По-годинне відвідування для локального часу',
	'VisitTime_ServerTime' => 'По-годинне відвідування для серверного часу',
	'VisitTime_WidgetLocalTime' => 'Відвідування по локальному часу',
	'VisitTime_WidgetServerTime' => 'Відвідування по серверному часу',
	'VisitTime_SubmenuTimes' => 'Разів',
	'VisitTime_NHour' => '',
	'VisitorInterest_VisitsPerDuration' => 'Відвідування за тривалістю',
	'VisitorInterest_VisitsPerNbOfPages' => 'Відвідування за кількістю сторінок',
	'VisitorInterest_WidgetLengths' => 'Тривалість відвідувань',
	'VisitorInterest_WidgetPages' => 'Кількість сторінок за відвідування',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Частота та Лояльність',
	'VisitorInterest_PlusXMin' => '%s хв',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s хв',
	'VisitorInterest_OnePage' => 'одна сторінка',
	'VisitorInterest_NPages' => '%s сторінок',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2s сек.',
	'VisitsSummary_NbVisits' => '%s відвідувань',
	'VisitsSummary_NbUniqueVisitors' => '%s унікальних відвідувачів',
	'VisitsSummary_NbActions' => '%s дій (переглядів сторінок)',
	'VisitsSummary_TotalTime' => '%s загальна кількість часу витрачена відвідувачами',
	'VisitsSummary_MaxNbActions' => '%s максимальна кількість переглядів сторінок за одне відвідування',
	'VisitsSummary_NbBounced' => '%s відвідувачів, що залишили сайт після перегляду однієї сторінки',
	'VisitsSummary_Evolution' => 'Динаміка за останні 30 %s',
	'VisitsSummary_Report' => 'Звіт',
	'VisitsSummary_GenerateTime' => '%s секунд на генерацію сторінки',
	'VisitsSummary_GenerateQueries' => '%s запитів виконано',
	'VisitsSummary_WidgetLastVisits' => 'Графік останніх відвідувань',
	'VisitsSummary_WidgetVisits' => 'Огляд відвідувань',
	'VisitsSummary_WidgetLastVisitors' => 'Графік останніх унікальних відвідувань',
	'VisitsSummary_WidgetOverviewGraph' => 'Огляд з графіком',
	'VisitsSummary_SubmenuOverview' => 'Огляд',
	'VisitsSummary_EvolutionPeriods' => 'Динаміка протягом останніх 30 %s',
);
